Module oo_bindgen::model
source · Expand description
Backend generators for target languages
Structs
Declares that the contained interface is asynchronous
Object-oriented class definition
C-style structure forward declaration
Settings that affect class method naming
Settings that affect collection function naming
Set of constants
An enum handle and a default validated variant
A type that wraps an inner enum and provides
information on how it maps to exceptions in
languages that support them
C function
represents a method that initiates an asynchronous operation
an eventually completes an abstract future
Settings that affect how things are named in future-style callback interfaces
An initializer defines how to construct a struct
Settings that affect C interface member naming
Settings that affect iterator function naming
metadata related to the library
Settings that affect the names of things
Represents an instance method on a class
Names in oo_bindgen are subset of allowed C-style identifiers. They are
enforce that names are a limited snake case.
Used for iterator “next” functions to get an optional primitive
Static class definition
represents a static method associated with a class
Marker class used to denote the String type with conversions to more specialized types
C-style structure definition
C-style structure forward declaration
Declares that the contained interface is synchronous only
Typed wrapper around an untyped struct declaration
SemVer version as defined by https://semver.org.
Struct handle combined with the validated name of one of it’s initializers.
The initializer may not take parameters
Enums
Basic types are trivially copyable. They can be used
in almost any context within the API model
Like a BasicType but with values
Types that can be used as a callback argument
Types allowed in callback function arguments
types that can be returned from callback functions
Types of constants available
Like CallbackReturnValue, but with a value
Durations may be represented in multiple ways in the underlying C API
Same as DurationType but with an associated value
Type of exception to generate (only used in Java atm)
Types that can be used in a function struct, some of which might have a default value
Types that can be used as native function arguments
Types that can be used in a function return value
types that can be returns from native functions
A flag to the backend that tells it whether or not
to optimize callbacks into Functors in the public API
This flag is only inspected for functional interfaces
Default value for a field in struct initializer
A numeric value
primitive types in most languages
same as primitive, but with a value
How to render a numeric constant
Structs refs can always be the Universal struct type, but may also be a
more specific type depending on context
Structs can always be the Universal struct type, but may also be a
more specific type depending on context
Types that can be used in a universal struct, some of which might have a default value
Validated doc reference