Enum oo_bindgen::model::DurationValue
source · Expand description
Same as DurationType but with an associated value
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Milliseconds(u64)
Duration is represented as a count of milliseconds in a u64 value
Seconds(u64)
Duration is represented as a count of seconds in a u64 value