#[non_exhaustive]
pub enum FunctionalTransform {
    Yes,
    No,
}
A flag to the backend that tells it whether or not to optimize callbacks into Functors in the public API This flag is only inspected for functional interfaces

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Yes

If the interface is functional, it should be optimized into functors if the language supports them



No

If the interface is functional, it will NOT be transformed

Implementations