#[non_exhaustive]
pub enum InitializerType {
    Normal,
    Static,
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Normal

Normal initializers map to actual language constructors A name is still required as some languages (e.g. C) don’t support associated constructors and require free-standing functions instead



Static

Static initializers are mapped to static methods in languages that support them (e.g. C++, Java, C#)