Enum oo_bindgen::model::UniversalDeclarationOr
source · #[non_exhaustive]
pub enum UniversalDeclarationOr<T>where
T: StructFieldType,{
Specific(TypedStructDeclaration<T>),
Universal(UniversalStructDeclaration),
}Expand description
Structs refs can always be the Universal struct type, but may also be a more specific type depending on context
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Specific(TypedStructDeclaration<T>)
Universal(UniversalStructDeclaration)
Implementations
sourceimpl<T> UniversalDeclarationOr<T>where
T: StructFieldType,
impl<T> UniversalDeclarationOr<T>where
T: StructFieldType,
pub fn untyped(&self) -> &StructDeclarationHandle