#[non_exhaustive]
pub enum Validated {
    Argument(Name),
    Class(ClassDeclarationHandle),
    ClassMethod(Handle<Class<Unvalidated>>, NameHandle<Function<Unvalidated>>),
    ClassConstructor(Handle<Class<Unvalidated>>, ClassConstructor<Unvalidated>),
    ClassDestructor(Handle<Class<Unvalidated>>, ClassDestructor<Unvalidated>),
    Struct(StructType<Unvalidated>),
    StructField(StructType<Unvalidated>, Name),
    Enum(Handle<Enum<Unvalidated>>),
    EnumVariant(Handle<Enum<Unvalidated>>, Name),
    Interface(Handle<Interface<Unvalidated>>),
    InterfaceMethod(Handle<Interface<Unvalidated>>, Name),
}
Validated doc reference

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Argument(Name)

Reference to an argument can only be used in docs for functions or callback methods



Class(ClassDeclarationHandle)

Reference a class



ClassMethod(Handle<Class<Unvalidated>>, NameHandle<Function<Unvalidated>>)

Reference a class method



ClassConstructor(Handle<Class<Unvalidated>>, ClassConstructor<Unvalidated>)

Reference to the class constructor



ClassDestructor(Handle<Class<Unvalidated>>, ClassDestructor<Unvalidated>)

Reference to the class destructor



Struct(StructType<Unvalidated>)

Reference a struct



StructField(StructType<Unvalidated>, Name)

Reference a field within a struct

Second parameter is the field name inside that struct



Enum(Handle<Enum<Unvalidated>>)

Reference an enum



EnumVariant(Handle<Enum<Unvalidated>>, Name)

Reference an enum variant



Interface(Handle<Interface<Unvalidated>>)

Reference an interface



InterfaceMethod(Handle<Interface<Unvalidated>>, Name)

Reference a method of a interface