pub struct InterfaceBuilder<'a> { /* private fields */ }

Implementations

Build the interface and mark it as only used in a synchronous context.

A synchronous interface is one that is invoked only during a function call which takes it as an argument. The Rust backend will NOT generate Send and Sync implementations so that it be cannot be transferred across thread boundaries.

Build the interface and mark it as used in an asynchronous context.

An asynchronous interface is one that is invoked some time after it is passed as a function argument. The Rust backend will mark the C representation of this interface as Send and Sync so that it be transferred across thread boundaries.