pub struct InterfaceSettings {
pub context_variable_name: Name,
pub destroy_func_name: Name,
}
Settings that affect C interface member naming
Name of the C void* context variable, defaults to “ctx”
Name of the function that destroys an interface when it is dropped, defaults to “on_destroy”
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.