pub struct LibraryBuilder { /* private fields */ }

Implementations

Define a structure that can be used in any context.

Backends will generate bi-directional conversion routines for this type of struct.

Define an opaque structure which must be of universal type

Define a structure that can be only be used in callback function arguments

Define a structure that can only be used as function return value

Define a structure that can only be be used as a function argument

Define an enumeration

A future interface is a specialized asynchronous which consists of a single callback method providing a single value. The callback represents the completion of a “future” and is mapped appropriately in backends.