Struct oo_bindgen::model::FutureSettings
source · pub struct FutureSettings {
pub success_callback_method_name: Name,
pub success_single_parameter_name: Name,
pub failure_callback_method_name: Name,
pub failure_single_parameter_name: Name,
pub async_method_callback_parameter_name: Name,
}Expand description
Settings that affect how things are named in future-style callback interfaces
Fields
success_callback_method_name: NameThe name given to the success completion method on interface
success_single_parameter_name: NameThe name given to the result parameter of the success completion method
failure_callback_method_name: NameThe name given to the failure completion method on interface
failure_single_parameter_name: NameThe name given to the error parameter of the failure completion method
async_method_callback_parameter_name: NameThe name given to the final callback parameter of the async methods